#!/usr/bin/env bash

cat >${ASSETS_DIR}/server.conf <<EOF
[req]
req_extensions = v3_req
distinguished_name = req_distinguished_name
prompt = no
[req_distinguished_name]
CN = model-serving-webhook.hops-system.svc
[ v3_req ]
basicConstraints = CA:FALSE
keyUsage = nonRepudiation, digitalSignature, keyEncipherment
extendedKeyUsage = clientAuth, serverAuth
subjectAltName = @alt_names
[alt_names]
DNS.1 = model-serving-webhook.hops-system.svc
EOF

# Generate the CA cert and private key
openssl req -nodes -new -x509 -keyout ${ASSETS_DIR}/model-serving-webhook-ca.key -out ${ASSETS_DIR}/model-serving-webhook-ca.crt -subj "/CN=Model Serving Webhook CA" -days 3650

# Generate the private key for the webhook server
openssl genrsa -out ${ASSETS_DIR}/model-serving-webhook.key ${MODEL_SERVING_KEY_SIZE}

# Generate a Certificate Signing Request (CSR) for the private key, and sign it with the private key of the CA.
openssl req -new -key ${ASSETS_DIR}/model-serving-webhook.key -subj "/CN=model-serving-webhook.hops-system.svc" -config ${ASSETS_DIR}/server.conf \
    | openssl x509 -req -CA ${ASSETS_DIR}/model-serving-webhook-ca.crt -CAkey ${ASSETS_DIR}/model-serving-webhook-ca.key -CAcreateserial -out ${ASSETS_DIR}/model-serving-webhook.crt -extensions v3_req -extfile ${ASSETS_DIR}/server.conf -days 3650


openssl base64 -A <"${ASSETS_DIR}/model-serving-webhook.crt" > ${MODEL_SERVING_CERT_BASE64_FILE}
