#!/usr/bin/env bash

_log_info "Configuring Prometheus and Grafana"

if $(grep -q "knative-controller" /srv/hops/prometheus/prometheus/prometheus.yml); then
    _log_info "Prometheus is already configured"
else 
    _log_info "Configure Prometheus"

    mkdir -p ${HOME}/.k8s_auth

    cat <<EOT > $HOME/.k8s_auth/gen_auth_token.sh
#!/usr/bin/env bash
set -xe
/usr/local/bin/kubectl create token -n hopsworks hopsworks-monitoring-serviceaccount > ${K8S_AUTH_TOKEN_FILE}
EOT

    chmod +x ${HOME}/.k8s_auth/gen_auth_token.sh

    echo "*/10 * * * * ${HOME}/.k8s_auth/gen_auth_token.sh >> ${HOME}/.k8s_auth/cron.log 2>&1" >> ${HOME}/.k8s_auth/cron_ek_auth_job
    crontab -u root ${HOME}/.k8s_auth/cron_ek_auth_job

    cp /srv/hops/prometheus/prometheus/prometheus.yml /srv/hops/prometheus/prometheus/prometheus.yml.bkp

    cat <<EOT > ${ASSETS_DIR}/eks_scrape_configs.py
import yaml
prometheus_yml = "/srv/hops/prometheus/prometheus/prometheus.yml"
with open("$ASSETS_DIR/prometheus_scrape_configs.yml") as f:
    config = yaml.load(f, Loader=yaml.SafeLoader)
    k8s_scrape_configs = config['scrape_configs']

with open(prometheus_yml) as f:
    curr_config = yaml.load(f, Loader=yaml.SafeLoader)
    curr_config['scrape_configs'].extend(k8s_scrape_configs)

with open(prometheus_yml, 'w') as f:
    yaml.dump(curr_config, f, sort_keys=False, default_flow_style=False)
EOT

    source /root/cloud-venv/bin/activate
    python ${ASSETS_DIR}/eks_scrape_configs.py
    systemctl restart prometheus
fi 


if $(grep -q "kserve" /srv/hops/grafana/conf/provisioning/dashboards/provisioning.yaml); then 
    _log_info "Grafana is already configured"
else
    _log_info "Configure Grafana"
    mkdir -p /srv/hops/grafana/conf/provisioning/dashboards/kserve
    mkdir -p /srv/hops/grafana/conf/provisioning/dashboards/kubernetes

    curl https://raw.githubusercontent.com/logicalclocks/hopsmonitor-chef/${HOPSWORKS_BRANCH}/files/default/dashboards/kserve/revision_metrics.json -o /srv/hops/grafana/conf/provisioning/dashboards/kserve/revision_metrics.json
    curl https://raw.githubusercontent.com/logicalclocks/hopsmonitor-chef/${HOPSWORKS_BRANCH}/files/default/dashboards/kubernetes/cluster.json -o /srv/hops/grafana/conf/provisioning/dashboards/kubernetes/cluster.json

    cat ${WORKING_DIR}/files/grafana_provisioning_kserve.yml >> /srv/hops/grafana/conf/provisioning/dashboards/provisioning.yaml

    systemctl restart grafana
fi 

_log_info "Prometheus and Grafana configuration is complete ..."

_log_info "Enable KServe"
$MYSQL_CLIENT hopsworks -e 'UPDATE variables SET value="true" WHERE id="kube_kserve_installed"'
$MYSQL_CLIENT hopsworks -e 'UPDATE variables SET value="true" WHERE id="enable_data_science_profile"'

_log_info "Setup KServe quotas"
$MYSQL_CLIENT hopsworks -e 'REPLACE INTO `hopsworks`.`variables`(`id`, `value`, `visibility`) VALUES("kube_serving_min_num_instances", "0", 1)'
$MYSQL_CLIENT hopsworks -e 'REPLACE INTO `hopsworks`.`variables`(`id`, `value`, `visibility`) VALUES("kube_serving_max_num_instances", "1", 1)'
$MYSQL_CLIENT hopsworks -e 'REPLACE INTO `hopsworks`.`variables`(`id`, `value`, `visibility`) VALUES("kube_serving_max_cores_allocation", "0.5", 1)'
$MYSQL_CLIENT hopsworks -e 'REPLACE INTO `hopsworks`.`variables`(`id`, `value`, `visibility`) VALUES("kube_serving_max_memory_allocation", "1024", 1)'
$MYSQL_CLIENT hopsworks -e 'REPLACE INTO `hopsworks`.`variables`(`id`, `value`, `visibility`) VALUES("kube_serving_max_gpus_allocation", "0", 1)'
$MYSQL_CLIENT hopsworks -e 'DELETE FROM `hopsworks`.`variables` WHERE `id`="kube_docker_cores_fraction"'

systemctl restart glassfish-domain1
